"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheStore = exports.StoreKey = void 0;
exports.StoreKey = {
    Config: 'dvc:config',
    User: 'dvc:user',
    AnonUserId: 'dvc:anonymous_user_id'
};
var CacheStore = /** @class */ (function () {
    function CacheStore(localStorage, logger) {
        this.store = localStorage;
        this.logger = logger;
    }
    CacheStore.prototype.save = function (storeKey, data) {
        var _a;
        (_a = this.store) === null || _a === void 0 ? void 0 : _a.setItem(storeKey, JSON.stringify(data));
    };
    CacheStore.prototype.load = function (storeKey) {
        var _a;
        return (_a = this.store) === null || _a === void 0 ? void 0 : _a.getItem(storeKey);
    };
    CacheStore.prototype.remove = function (storeKey) {
        var _a;
        (_a = this.store) === null || _a === void 0 ? void 0 : _a.removeItem(storeKey);
    };
    CacheStore.prototype.saveConfig = function (data) {
        var _a;
        this.save(exports.StoreKey.Config, data);
        (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info('Successfully saved config to local storage');
    };
    CacheStore.prototype.loadConfig = function () {
        var config = this.load(exports.StoreKey.Config);
        return config ? JSON.parse(config) : config;
    };
    CacheStore.prototype.saveUser = function (user) {
        var _a;
        if (!user) {
            throw new Error('No user to save');
        }
        this.save(exports.StoreKey.User, user);
        (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info('Successfully saved user to local storage');
    };
    CacheStore.prototype.loadUser = function () {
        var user = this.load(exports.StoreKey.User);
        return user ? JSON.parse(user) : user;
    };
    CacheStore.prototype.saveAnonUserId = function (userId) {
        var _a;
        this.save(exports.StoreKey.AnonUserId, userId);
        (_a = this.logger) === null || _a === void 0 ? void 0 : _a.info('Successfully saved anonymous user id to local storage');
    };
    CacheStore.prototype.loadAnonUserId = function () {
        var anonUserId = this.load(exports.StoreKey.AnonUserId);
        return anonUserId ? JSON.parse(anonUserId) : anonUserId;
    };
    return CacheStore;
}());
exports.CacheStore = CacheStore;
exports.default = CacheStore;
//# sourceMappingURL=CacheStore.js.map